<?php

namespace Drupal\paragraph_lineage\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Annotation\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Url;
use Drupal\Core\Entity\EntityInterface;

/**
 * Plugin implementation of the 'paragraph_parent_link' formatter.
 *
 * @FieldFormatter(
 *   id = "paragraph_parent_link",
 *   label = @Translation("Link to Parent Entity"),
 *   field_types = {
 *     "integer"
 *   }
 * )
 */
class ParagraphParentLinkFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    foreach ($items as $delta => $item) {
      if ($item->value) {
        // Get the paragraph entity.
        $paragraph = $item->getEntity();
        $parent_entity = $paragraph->getParentEntity();


          if ($parent_entity instanceof EntityInterface) {
            // Generate the URL to the parent entity's canonical route.
            $url = $this->getParentEntityUrl($parent_entity);
            $link_text = $this->t('@type: @label', [
              '@type' => $parent_entity->getEntityTypeId(),
              '@label' => $parent_entity->label() ?: $this->t('View Parent'),
            ]);

            // Build the link.
            $elements[$delta] = [
              '#type' => 'link',
              '#title' => $link_text,
              '#url' => $url,
            ];
          }
        }
      }

    return $elements;
  }

  /**
   * Generate the URL to the parent entity's canonical route.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The parent entity.
   *
   * @return \Drupal\Core\Url
   *   The URL object.
   */
  protected function getParentEntityUrl(EntityInterface $entity): Url {
    $entity_type_id = $entity->getEntityTypeId();
    $route_name = "entity.{$entity_type_id}.canonical";

    return Url::fromRoute($route_name, [$entity_type_id => $entity->id()]);
  }
}
